@@ -49,9 +49,9 @@ class TestTypeCreate(TestType):
     def setUp(self):
         super(TestTypeCreate, self).setUp()
 
-        self.new_volume_type = volume_fakes.FakeType.create_one_type(
-            methods={'set_keys': {'myprop': 'myvalue'}}
-        )
+        self.new_volume_type = \
+            volume_fakes.FakeVolumeType.create_one_volume_type(
+                methods={'set_keys': {'myprop': 'myvalue'}})
         self.data = (
             self.new_volume_type.description,
             self.new_volume_type.id,
@@ -78,7 +78,7 @@ class TestTypeCreate(TestType):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_type_create_with_encryption(self):
         encryption_info = {
@@ -87,11 +87,12 @@ class TestTypeCreate(TestType):
             'key_size': '128',
             'control_location': 'front-end',
         }
-        encryption_type = volume_fakes.FakeType.create_one_encryption_type(
-            attrs=encryption_info
-        )
-        self.new_volume_type = volume_fakes.FakeType.create_one_type(
-            attrs={'encryption': encryption_info})
+        encryption_type = \
+            volume_fakes.FakeVolumeType.create_one_encryption_volume_type(
+                attrs=encryption_info)
+        self.new_volume_type = \
+            volume_fakes.FakeVolumeType.create_one_volume_type(
+                attrs={'encryption': encryption_info})
         self.types_mock.create.return_value = self.new_volume_type
         self.encryption_types_mock.create.return_value = encryption_type
         encryption_columns = (
@@ -139,17 +140,17 @@ class TestTypeCreate(TestType):
             body,
         )
         self.assertEqual(encryption_columns, columns)
-        self.assertItemsEqual(encryption_data, data)
+        self.assertCountEqual(encryption_data, data)
 
 
 class TestTypeDelete(TestType):
 
-    volume_types = volume_fakes.FakeType.create_types(count=2)
+    volume_types = volume_fakes.FakeVolumeType.create_volume_types(count=2)
 
     def setUp(self):
         super(TestTypeDelete, self).setUp()
 
-        self.types_mock.get = volume_fakes.FakeType.get_types(
+        self.types_mock.get = volume_fakes.FakeVolumeType.get_volume_types(
             self.volume_types)
         self.types_mock.delete.return_value = None
 
@@ -220,7 +221,7 @@ class TestTypeDelete(TestType):
 
 class TestTypeList(TestType):
 
-    volume_types = volume_fakes.FakeType.create_types()
+    volume_types = volume_fakes.FakeVolumeType.create_volume_types()
 
     columns = [
         "ID",
@@ -270,7 +271,7 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.list.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_type_list_with_options(self):
         arglist = [
@@ -284,11 +285,12 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.list.assert_called_once_with()
         self.assertEqual(self.columns_long, columns)
-        self.assertItemsEqual(self.data_long, list(data))
+        self.assertCountEqual(self.data_long, list(data))
 
     def test_type_list_with_encryption(self):
-        encryption_type = volume_fakes.FakeType.create_one_encryption_type(
-            attrs={'volume_type_id': self.volume_types[0].id})
+        encryption_type = \
+            volume_fakes.FakeVolumeType.create_one_encryption_volume_type(
+                attrs={'volume_type_id': self.volume_types[0].id})
         encryption_info = {
             'provider': 'LuksEncryptor',
             'cipher': None,
@@ -328,12 +330,12 @@ class TestTypeList(TestType):
         self.encryption_types_mock.list.assert_called_once_with()
         self.types_mock.list.assert_called_once_with()
         self.assertEqual(encryption_columns, columns)
-        self.assertItemsEqual(encryption_data, list(data))
+        self.assertCountEqual(encryption_data, list(data))
 
 
 class TestTypeSet(TestType):
 
-    volume_type = volume_fakes.FakeType.create_one_type(
+    volume_type = volume_fakes.FakeVolumeType.create_one_volume_type(
         methods={'set_keys': None})
 
     def setUp(self):
@@ -441,7 +443,7 @@ class TestTypeShow(TestType):
     def setUp(self):
         super(TestTypeShow, self).setUp()
 
-        self.volume_type = volume_fakes.FakeType.create_one_type()
+        self.volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
         self.data = (
             self.volume_type.description,
             self.volume_type.id,
@@ -469,17 +471,18 @@ class TestTypeShow(TestType):
         self.types_mock.get.assert_called_with(self.volume_type.id)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_type_show_with_encryption(self):
-        encryption_type = volume_fakes.FakeType.create_one_encryption_type()
+        encryption_type = \
+            volume_fakes.FakeVolumeType.create_one_encryption_volume_type()
         encryption_info = {
             'provider': 'LuksEncryptor',
             'cipher': None,
             'key_size': None,
             'control_location': 'front-end',
         }
-        self.volume_type = volume_fakes.FakeType.create_one_type(
+        self.volume_type = volume_fakes.FakeVolumeType.create_one_volume_type(
             attrs={'encryption': encryption_info})
         self.types_mock.get.return_value = self.volume_type
         self.encryption_types_mock.get.return_value = encryption_type
@@ -513,12 +516,12 @@ class TestTypeShow(TestType):
         self.types_mock.get.assert_called_with(self.volume_type.id)
         self.encryption_types_mock.get.assert_called_with(self.volume_type.id)
         self.assertEqual(encryption_columns, columns)
-        self.assertItemsEqual(encryption_data, data)
+        self.assertCountEqual(encryption_data, data)
 
 
 class TestTypeUnset(TestType):
 
-    volume_type = volume_fakes.FakeType.create_one_type(
+    volume_type = volume_fakes.FakeVolumeType.create_one_volume_type(
         methods={'unset_keys': None})
 
     def setUp(self):
@@ -596,7 +599,7 @@ class TestTypeUnset(TestType):
 class TestColumns(TestType):
 
     def test_encryption_info_column_with_info(self):
-        fake_volume_type = volume_fakes.FakeType.create_one_type()
+        fake_volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
         type_id = fake_volume_type.id
 
         encryption_info = {
@@ -612,7 +615,7 @@ class TestColumns(TestType):
         self.assertEqual(encryption_info, col.machine_readable())
 
     def test_encryption_info_column_without_info(self):
-        fake_volume_type = volume_fakes.FakeType.create_one_type()
+        fake_volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
         type_id = fake_volume_type.id
 
         col = volume_type.EncryptionInfoColumn(type_id, {})
