@@ -14,9 +14,8 @@
 #
 
 import copy
-
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
@@ -40,7 +39,7 @@ class TestQos(volume_fakes.TestVolume):
 
 class TestQosAssociate(TestQos):
 
-    volume_type = volume_fakes.FakeType.create_one_type()
+    volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
     qos_spec = volume_fakes.FakeQos.create_one_qos()
 
     def setUp(self):
@@ -113,7 +112,7 @@ class TestQosCreate(TestQos):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_qos_create_with_consumer(self):
         arglist = [
@@ -134,7 +133,7 @@ class TestQosCreate(TestQos):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_qos_create_with_properties(self):
         arglist = [
@@ -160,7 +159,7 @@ class TestQosCreate(TestQos):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
 
 class TestQosDelete(TestQos):
@@ -256,7 +255,7 @@ class TestQosDelete(TestQos):
 
 class TestQosDisassociate(TestQos):
 
-    volume_type = volume_fakes.FakeType.create_one_type()
+    volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
     qos_spec = volume_fakes.FakeQos.create_one_qos()
 
     def setUp(self):
@@ -343,7 +342,7 @@ class TestQosList(TestQos):
         self.qos_mock.list.assert_called_with()
 
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_qos_list_no_association(self):
         self.qos_mock.reset_mock()
@@ -370,7 +369,7 @@ class TestQosList(TestQos):
             format_columns.ListColumn(None),
             format_columns.DictColumn(self.qos_specs[1].specs),
         )
-        self.assertListItemEqual(ex_data, list(data))
+        self.assertCountEqual(ex_data, list(data))
 
 
 class TestQosSet(TestQos):
@@ -450,7 +449,7 @@ class TestQosShow(TestQos):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, tuple(data))
+        self.assertCountEqual(self.data, tuple(data))
 
 
 class TestQosUnset(TestQos):
