@@ -12,9 +12,10 @@
 #   under the License.
 #
 
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
+from cinderclient import api_versions
 from osc_lib import exceptions
 from osc_lib import utils
 
@@ -114,6 +115,104 @@ class TestBackupCreate(TestBackup):
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
+    def test_backup_create_with_properties(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.43')
+
+        arglist = [
+            "--property", "foo=bar",
+            "--property", "wow=much-cool",
+            self.new_backup.volume_id,
+        ]
+        verifylist = [
+            ("properties", {"foo": "bar", "wow": "much-cool"}),
+            ("volume", self.new_backup.volume_id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.backups_mock.create.assert_called_with(
+            self.new_backup.volume_id,
+            container=None,
+            name=None,
+            description=None,
+            force=False,
+            incremental=False,
+            metadata={"foo": "bar", "wow": "much-cool"},
+        )
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, data)
+
+    def test_backup_create_with_properties_pre_v343(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.42')
+
+        arglist = [
+            "--property", "foo=bar",
+            "--property", "wow=much-cool",
+            self.new_backup.volume_id,
+        ]
+        verifylist = [
+            ("properties", {"foo": "bar", "wow": "much-cool"}),
+            ("volume", self.new_backup.volume_id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        exc = self.assertRaises(
+            exceptions.CommandError,
+            self.cmd.take_action,
+            parsed_args)
+        self.assertIn("--os-volume-api-version 3.43 or greater", str(exc))
+
+    def test_backup_create_with_availability_zone(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.51')
+
+        arglist = [
+            "--availability-zone", "my-az",
+            self.new_backup.volume_id,
+        ]
+        verifylist = [
+            ("availability_zone", "my-az"),
+            ("volume", self.new_backup.volume_id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.backups_mock.create.assert_called_with(
+            self.new_backup.volume_id,
+            container=None,
+            name=None,
+            description=None,
+            force=False,
+            incremental=False,
+            availability_zone="my-az",
+        )
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, data)
+
+    def test_backup_create_with_availability_zone_pre_v351(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.50')
+
+        arglist = [
+            "--availability-zone", "my-az",
+            self.new_backup.volume_id,
+        ]
+        verifylist = [
+            ("availability_zone", "my-az"),
+            ("volume", self.new_backup.volume_id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        exc = self.assertRaises(
+            exceptions.CommandError,
+            self.cmd.take_action,
+            parsed_args)
+        self.assertIn("--os-volume-api-version 3.51 or greater", str(exc))
+
     def test_backup_create_without_name(self):
         arglist = [
             "--description", self.new_backup.description,
@@ -136,7 +235,6 @@ class TestBackupCreate(TestBackup):
             description=self.new_backup.description,
             force=False,
             incremental=False,
-            snapshot_id=None,
         )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
@@ -240,18 +338,18 @@ class TestBackupList(TestBackup):
     backups = volume_fakes.FakeBackup.create_backups(
         attrs={'volume_id': volume.name}, count=3)
 
-    columns = [
+    columns = (
         'ID',
         'Name',
         'Description',
         'Status',
         'Size',
-    ]
-    columns_long = columns + [
+    )
+    columns_long = columns + (
         'Availability Zone',
         'Volume',
         'Container',
-    ]
+    )
 
     data = []
     for b in backups:
@@ -314,7 +412,7 @@ class TestBackupList(TestBackup):
             limit=None,
         )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_backup_list_with_options(self):
         arglist = [
@@ -353,46 +451,108 @@ class TestBackupList(TestBackup):
             limit=3,
         )
         self.assertEqual(self.columns_long, columns)
-        self.assertListItemEqual(self.data_long, list(data))
+        self.assertCountEqual(self.data_long, list(data))
 
 
 class TestBackupRestore(TestBackup):
 
     volume = volume_fakes.FakeVolume.create_one_volume()
     backup = volume_fakes.FakeBackup.create_one_backup(
-        attrs={'volume_id': volume.id})
+        attrs={'volume_id': volume.id},
+    )
 
     def setUp(self):
-        super(TestBackupRestore, self).setUp()
+        super().setUp()
 
         self.backups_mock.get.return_value = self.backup
         self.volumes_mock.get.return_value = self.volume
         self.restores_mock.restore.return_value = (
             volume_fakes.FakeVolume.create_one_volume(
-                {'id': self.volume['id']}))
+                {'id': self.volume['id']},
+            )
+        )
         # Get the command object to mock
         self.cmd = volume_backup.RestoreVolumeBackup(self.app, None)
 
     def test_backup_restore(self):
+        self.volumes_mock.get.side_effect = exceptions.CommandError()
+        self.volumes_mock.find.side_effect = exceptions.CommandError()
         arglist = [
-            self.backup.id,
-            self.backup.volume_id
+            self.backup.id
         ]
         verifylist = [
             ("backup", self.backup.id),
-            ("volume", self.backup.volume_id)
+            ("volume", None),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
-        self.restores_mock.restore.assert_called_with(self.backup.id,
-                                                      self.backup.volume_id)
+        self.restores_mock.restore.assert_called_with(
+            self.backup.id, None, None,
+        )
         self.assertIsNotNone(result)
 
+    def test_backup_restore_with_volume(self):
+        self.volumes_mock.get.side_effect = exceptions.CommandError()
+        self.volumes_mock.find.side_effect = exceptions.CommandError()
+        arglist = [
+            self.backup.id,
+            self.backup.volume_id,
+        ]
+        verifylist = [
+            ("backup", self.backup.id),
+            ("volume", self.backup.volume_id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+        self.restores_mock.restore.assert_called_with(
+            self.backup.id, None, self.backup.volume_id,
+        )
+        self.assertIsNotNone(result)
+
+    def test_backup_restore_with_volume_force(self):
+        arglist = [
+            "--force",
+            self.backup.id,
+            self.volume.name,
+        ]
+        verifylist = [
+            ("force", True),
+            ("backup", self.backup.id),
+            ("volume", self.volume.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+        self.restores_mock.restore.assert_called_with(
+            self.backup.id, self.volume.id, None,
+        )
+        self.assertIsNotNone(result)
+
+    def test_backup_restore_with_volume_existing(self):
+        arglist = [
+            self.backup.id,
+            self.volume.name,
+        ]
+        verifylist = [
+            ("backup", self.backup.id),
+            ("volume", self.volume.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.assertRaises(
+            exceptions.CommandError,
+            self.cmd.take_action,
+            parsed_args,
+        )
+
 
 class TestBackupSet(TestBackup):
 
-    backup = volume_fakes.FakeBackup.create_one_backup()
+    backup = volume_fakes.FakeBackup.create_one_backup(
+        attrs={'metadata': {'wow': 'cool'}},
+    )
 
     def setUp(self):
         super(TestBackupSet, self).setUp()
@@ -403,6 +563,9 @@ class TestBackupSet(TestBackup):
         self.cmd = volume_backup.SetVolumeBackup(self.app, None)
 
     def test_backup_set_name(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.9')
+
         arglist = [
             '--name', 'new_name',
             self.backup.id,
@@ -420,7 +583,30 @@ class TestBackupSet(TestBackup):
             self.backup.id, **{'name': 'new_name'})
         self.assertIsNone(result)
 
+    def test_backup_set_name_pre_v39(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.8')
+
+        arglist = [
+            '--name', 'new_name',
+            self.backup.id,
+        ]
+        verifylist = [
+            ('name', 'new_name'),
+            ('backup', self.backup.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        exc = self.assertRaises(
+            exceptions.CommandError,
+            self.cmd.take_action,
+            parsed_args)
+        self.assertIn("--os-volume-api-version 3.9 or greater", str(exc))
+
     def test_backup_set_description(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.9')
+
         arglist = [
             '--description', 'new_description',
             self.backup.id,
@@ -444,6 +630,27 @@ class TestBackupSet(TestBackup):
         )
         self.assertIsNone(result)
 
+    def test_backup_set_description_pre_v39(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.8')
+
+        arglist = [
+            '--description', 'new_description',
+            self.backup.id,
+        ]
+        verifylist = [
+            ('name', None),
+            ('description', 'new_description'),
+            ('backup', self.backup.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        exc = self.assertRaises(
+            exceptions.CommandError,
+            self.cmd.take_action,
+            parsed_args)
+        self.assertIn("--os-volume-api-version 3.9 or greater", str(exc))
+
     def test_backup_set_state(self):
         arglist = [
             '--state', 'error',
@@ -482,6 +689,159 @@ class TestBackupSet(TestBackup):
         self.backups_mock.reset_state.assert_called_with(
             self.backup.id, 'error')
 
+    def test_backup_set_no_property(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.43')
+
+        arglist = [
+            '--no-property',
+            self.backup.id,
+        ]
+        verifylist = [
+            ('no_property', True),
+            ('backup', self.backup.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        kwargs = {
+            'metadata': {},
+        }
+        self.backups_mock.update.assert_called_once_with(
+            self.backup.id,
+            **kwargs
+        )
+        self.assertIsNone(result)
+
+    def test_backup_set_no_property_pre_v343(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.42')
+
+        arglist = [
+            '--no-property',
+            self.backup.id,
+        ]
+        verifylist = [
+            ('no_property', True),
+            ('backup', self.backup.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        exc = self.assertRaises(
+            exceptions.CommandError,
+            self.cmd.take_action,
+            parsed_args)
+        self.assertIn("--os-volume-api-version 3.43 or greater", str(exc))
+
+    def test_backup_set_property(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.43')
+
+        arglist = [
+            '--property', 'foo=bar',
+            self.backup.id,
+        ]
+        verifylist = [
+            ('properties', {'foo': 'bar'}),
+            ('backup', self.backup.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        kwargs = {
+            'metadata': {'wow': 'cool', 'foo': 'bar'},
+        }
+        self.backups_mock.update.assert_called_once_with(
+            self.backup.id,
+            **kwargs
+        )
+        self.assertIsNone(result)
+
+    def test_backup_set_property_pre_v343(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.42')
+
+        arglist = [
+            '--property', 'foo=bar',
+            self.backup.id,
+        ]
+        verifylist = [
+            ('properties', {'foo': 'bar'}),
+            ('backup', self.backup.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        exc = self.assertRaises(
+            exceptions.CommandError,
+            self.cmd.take_action,
+            parsed_args)
+        self.assertIn("--os-volume-api-version 3.43 or greater", str(exc))
+
+
+class TestBackupUnset(TestBackup):
+
+    backup = volume_fakes.FakeBackup.create_one_backup(
+        attrs={'metadata': {'foo': 'bar'}},
+    )
+
+    def setUp(self):
+        super().setUp()
+
+        self.backups_mock.get.return_value = self.backup
+
+        # Get the command object to test
+        self.cmd = volume_backup.UnsetVolumeBackup(self.app, None)
+
+    def test_backup_unset_property(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.43')
+
+        arglist = [
+            '--property', 'foo',
+            self.backup.id,
+        ]
+        verifylist = [
+            ('properties', ['foo']),
+            ('backup', self.backup.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        kwargs = {
+            'metadata': {},
+        }
+        self.backups_mock.update.assert_called_once_with(
+            self.backup.id,
+            **kwargs
+        )
+        self.assertIsNone(result)
+
+    def test_backup_unset_property_pre_v343(self):
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.42')
+
+        arglist = [
+            '--property', 'foo',
+            self.backup.id,
+        ]
+        verifylist = [
+            ('properties', ['foo']),
+            ('backup', self.backup.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        exc = self.assertRaises(
+            exceptions.CommandError,
+            self.cmd.take_action,
+            parsed_args)
+        self.assertIn("--os-volume-api-version 3.43 or greater", str(exc))
+
 
 class TestBackupShow(TestBackup):
 
